@@ -23,8 +23,11 @@ echo "##################"
 oc create -n ${ELASTICSEARCH_OPERATOR_NAMESPACE} -f olm_deploy/subscription/operator-group.yaml
 
 # create the subscription
-export OPERATOR_PACKAGE_CHANNEL=\"$(grep name manifests/elasticsearch-operator.package.yaml | grep  -oh "[0-9]\+\.[0-9]\+")\"
-envsubst < olm_deploy/subscription/subscription.yaml | oc create -n ${ELASTICSEARCH_OPERATOR_NAMESPACE} -f -
+export OPERATOR_PACKAGE_CHANNEL="stable"
+subscription=$(envsubst < olm_deploy/subscription/subscription.yaml)
+echo "Creating:"
+echo "$subscription"
+echo "$subscription" | oc create -n ${ELASTICSEARCH_OPERATOR_NAMESPACE} -f -
 
 olm_deploy/scripts/wait_for_deployment.sh ${ELASTICSEARCH_OPERATOR_NAMESPACE} elasticsearch-operator
 oc wait -n ${ELASTICSEARCH_OPERATOR_NAMESPACE} --timeout=180s --for=condition=available deployment/elasticsearch-operator
